@@ -21,7 +21,7 @@ from werkzeug.datastructures import ImmutableDict
 from werkzeug.routing import RequestRedirect, Rule
 
 from .helpers import _Kouzi, findPackage, getHandlerAction, getModulesFromPyFile, getEnviron, \
-                     lockedCachedProperty, getTemplater
+                    lockedCachedProperty, getTemplater
 from .contexts import RequestContext, AppContext
 from .routing import Router
 from core.config import RESTFUL_ACTIONS
@@ -36,8 +36,9 @@ from shimehari.core.signals import appContextTearingDown, requestContextTearingD
 
 _loggerLock = Lock()
 
+
 def setupMethod(f):
-    def wrapperFunc(self, *args,**kwargs):
+    def wrapperFunc(self, *args, **kwargs):
         if self.debug or self._gotFirstRequest:
             raise AssertionError('Setup seems to have already completed ...')
         return f(self, *args, **kwargs)
@@ -45,6 +46,30 @@ def setupMethod(f):
 
 
 class Shimehari(_Kouzi):
+    u"""Shimehari Object は WSGI アプリケーションとして必要な機能を実装しており、
+    アプリケーションの中心となるオブジェクトです。
+
+    メインモジュール、または __init__.py ファイルの中で以下のように書くことで
+    Shimehari インスタンスを生成することができます。
+
+    .. code-block:: python
+
+        from shimehari import Shimehari
+        app = Shimehari(__name__)
+
+    ただし、Shimehari では通常コマンドラインでアプリケーションを生成することを推奨しているので
+    あなたが直接インスタンス生成のコードを書くことはそうそうないと思われます。
+
+    :param importName: アプリケーションのパッケージ名
+    :param staticURL: サイト内共通、静的ファイルの URL
+    :param staticFolder: 静的ファイルが格納されているディレクトリ
+    :param appFolder: アプリケーション全体が格納されているディレクトリ
+    :param controllerFolder: コントローラーが格納されているディレクトリ
+    :param viewFolder: ビューが格納されているディレクトリ
+    :param assetsFolder: アセットファイルが格納されているディレクトリ
+    :param instancePath: アプリケーションのための代替インスタンスパス
+
+    """
 
     currentEnv = getEnviron()
     debug = None
@@ -58,20 +83,20 @@ class Shimehari(_Kouzi):
     teardownAppContextFuncs = []
 
     defaultConfig = {
-        'DEBUG':False,
-        'TEST':False,
-        'APP_DIRECTORY':'app',
-        'CONTROLLER_DIRECTORY':'controllers',
-        'VIEW_DIRECTORY':'views',
+        'DEBUG': False,
+        'TEST': False,
+        'APP_DIRECTORY': 'app',
+        'CONTROLLER_DIRECTORY': 'controllers',
+        'VIEW_DIRECTORY': 'views',
         #for daiginjou
-        'MODEL_DIRECTORY':'models',
-        'PREFERRED_URL_SCHEME':'http',
-        'AUTO_SETUP':True,
-        'TEMPLATE_ENGINE':'jinja2',
-        'TRAP_HTTP_EXCEPTIONS':False,
-        'SERVER_NAME':None,
-        'PERMANENT_SESSION_LIFETIME':timedelta(days=31),
-        'SECRET_KEY':'_secret_shimehari'
+        'MODEL_DIRECTORY': 'models',
+        'PREFERRED_URL_SCHEME': 'http',
+        'AUTO_SETUP': True,
+        'TEMPLATE_ENGINE': 'jinja2',
+        'TRAP_HTTP_EXCEPTIONS': False,
+        'SERVER_NAME': None,
+        'PERMANENT_SESSION_LIFETIME': timedelta(days=31),
+        'SECRET_KEY': '_secret_shimehari'
     }
 
     templateOptions = {}
@@ -80,15 +105,15 @@ class Shimehari(_Kouzi):
 
     sharedRequestClass = _SharedRequestClass
 
-    def __init__(self, importName, 
+    def __init__(self, importName,
                  staticURL=None, staticFolder='static',
-                 appFolder='app', controllerFolder='controllers', 
+                 appFolder='app', controllerFolder='controllers',
                  viewFolder='views', assetsFolder='assets',
-                 instancePath=None, isRelativeConfig=False,templateOptions={}):
+                 instancePath=None, isRelativeConfig=False, templateOptions={}):
 
-        _Kouzi.__init__(self, importName, appFolder=appFolder, 
+        _Kouzi.__init__(self, importName, appFolder=appFolder,
                         controllerFolder=controllerFolder, viewFolder=viewFolder)
-        
+
         if instancePath is None:
             self._instancePath = self.getInstancePath()
 
@@ -97,7 +122,6 @@ class Shimehari(_Kouzi):
 
         self.config = self.getConfig()
 
-
         self.controllers = {}
         self.urlValuePreprocesors = {}
         self.beforeRequestFuncs = {}
@@ -105,7 +129,7 @@ class Shimehari(_Kouzi):
         self.urlDefaultFuncs = {}
         self.afterRequestFuncs = {}
         self._errorHandlers = {}
-        self.errorHandlerSpec = {None:self._errorHandlers}
+        self.errorHandlerSpec = {None: self._errorHandlers}
         self.buildErrorHandlers = None
         self.teardownRequestContextFuncs = {}
 
@@ -129,23 +153,18 @@ class Shimehari(_Kouzi):
         self.useXSendFile = self.config['USE_X_SENDFILE']
 
         self.templateOptions = templateOptions
-        
+
         if self.config['AUTO_SETUP']:
             self.setup()
 
-
     @property
-    def gotFirstRequest(self):        
+    def gotFirstRequest(self):
         return self._gotFirstRequest
 
-
-
     @property
     def propagateExceptions(self):
         return self.testing or self.debug
 
-
-
     @property
     def preserveContextOnException(self):
         rv = self.config['PRESERVE_CONTEXT_ON_EXCEPTION']
@@ -153,7 +172,6 @@ class Shimehari(_Kouzi):
             return rv
         return self.debug
 
-
     @property
     def logger(self):
         if self._logger and self._logger.name == self.loggerName:
@@ -165,61 +183,33 @@ class Shimehari(_Kouzi):
             self._logger = rv = createLogger(self.loggerName)
             return rv
 
-
-    u"""--------------------------------------
-        ルーティング
-    --------------------------------------"""
     def router():
-        doc = "The router property."
+        u"""アプリケーションのルーティングを管理するルーターを設定します。"""
         def fget(self):
             return self._router
+
         def fset(self, value):
             self.setControllerFromRouter(value)
             self._router = value
+
         def fdel(self):
             self.controllers = {}
             del self._router
         return locals()
     router = property(**router())
 
-
-
-    """
-    ===============================
-        methods
-    ===============================
-    """
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        getInstancePath
-        ~~~~~~~~~~~~~~~
-
-        インスタンスパスを返します。
-        [return]
-            :str インスタンスパス
-    ------------------------------"""
     def getInstancePath(self):
+        u"""インスタンスパスを返します。"""
         prefix, pkgPath = findPackage(self.importName)
         if prefix is None:
             return os.path.join(pkgPath, 'instance')
         return os.path.join(prefix, 'var', self.name + '-instance')
 
-
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        getConfig
-        ~~~~~~~~~
-
-        現在の コンフィグ を返します。
-        [return]
-            :Config 現在のコンフィグ
-    ------------------------------"""
     def getConfig(self):
+        u"""現在アプリケーションに適用されているコンフィグを返します。"""
         configs = ConfigManager.getConfigs()
         try:
-            from .config import config
+            # from .config import config
             configs = ConfigManager.getConfigs()
         except ImportError:
             pass
@@ -230,16 +220,18 @@ class Shimehari(_Kouzi):
         else:
             return configs[self.currentEnv]
 
-
-
     def saveSession(self, session, response):
+        u"""セッションを保存します。
+
+        :param session:     保存したいセッション
+        :param response:    レスポンス
+
+        """
         if session.should_save:
             self.sessionStore.save(session, response)
             response.set_cookie(self.sessionKey, session.sid)
         return response
 
-
-
     def openSession(self, request):
         sid = request.cookies.get(self.sessionKey, None)
         if sid is None:
@@ -247,241 +239,148 @@ class Shimehari(_Kouzi):
         else:
             return self.sessionStore.get(sid)
 
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        setControllerFromRouter
-        ~~~~~~~~~~~~~~~~~~~~~~~
-
-        ルーターからコントローラーを設定します。
-        [args]
-        :router
-            るーたー
-    ------------------------------"""
     def setControllerFromRouter(self, router):
+        u"""設定されたルーターからコントローラーをバインディングします。
+
+        :param router: ルーター
+        """
         if not self.controllers:
             self.controllers = {}
         for rule in router._rules:
             self.controllers[rule.endpoint] = rule.endpoint
 
-
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        addController
-        ~~~~~~~~~~~~~
-
-        [args]
-        :controller
-            追加したいコントローラー
-            追加されたコントローラーは
-            アプリケーションの管理下に置かれ、
-            ルーティングが自動生成されます。
-    ------------------------------"""
     def addController(self, controller):
+        u"""アプリケーションにコントローラーを追加します。
+
+        :param controller:  追加したいコントローラー。
+                            追加されたコントローラーはアプリケーションの管理下に置かれ、
+                            ルーティングが自動生成されます。
+        """
         for action in RESTFUL_ACTIONS:
             handler = getHandlerAction(controller, action)
             if handler is not None:
                 self.controllers[handler] = handler
 
-
-
     def addRoute(self, url, func, methods=None, **options):
         rule = Rule(url, endpoint=func.__name__, methods=methods)
         self.controllers[func.__name__] = func
         self.router.add(rule)
 
-
-
     def logException(self, excInfo):
         self.logger.error('excepts on %s [%s]' % (request.path, request.method), exc_info=excInfo)
 
-
-
     def injectURLDefaults(self, endpoint, values):
-        funcs = self.urlDefaultFuncs.get(None,())
+        funcs = self.urlDefaultFuncs.get(None, ())
         for func in funcs:
-            func(endpoint, vlaues)
-
-
+            func(endpoint, values)
 
     @lockedCachedProperty
     def templateLoader(self):
         return self.templater.templateLoader
 
-
-
     @lockedCachedProperty
     def templateEnv(self):
         rv = self.templater.templateEnv()
         return rv
 
-
-
     def createTemplateEnvironment(self):
         rv = self.templater.createTemplateEnvironment()
         return rv
 
-
-
     def createGlobalTemplateLoader(self):
         return self.templater.dispatchLoader(self)
 
-
-
-    def updateTemplateContext(self,context):
+    def updateTemplateContext(self, context):
         self.templater.updateTemplateContext(context)
 
-
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        setup
-        ~~~~~
-
-        アプリケーションをセットアップします。
-        指定された app ディレクトリ配下にある
-        コントローラー、ルーターを探し出しバインドします。
-
-    ------------------------------"""
     def setup(self):
+        u"""アプリケーションをセットアップします。
+            指定された app ディレクトリ配下にあるコントローラー、ルーターを探し出しバインドします。
+        """
         self.appPath = os.path.join(self.rootPath, self.appFolder)
         if not os.path.isdir(self.appPath):
             raise ShimehariSetupError('Application directory is not found\n%s' % self.rootPath)
             sys.exit(0)
         try:
-            apps = __import__(self.appFolder)
+            __import__(self.appFolder)
             self.setupTemplater()
             self.setupBindController()
             self.setupBindRouter()
         except (ImportError, AttributeError):
             raise ShimehariSetupError('Application directory is invalid')
 
-
     def setupTemplater(self):
         try:
-            self.templater = getTemplater(self, self.config['TEMPLATE_ENGINE'],templateOptions=self.templateOptions)
+            self.templater = getTemplater(self, self.config['TEMPLATE_ENGINE'], templateOptions=self.templateOptions)
         except Exception, e:
             raise ShimehariSetupError('setup template engine was failed... \n%s' % e)
 
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        setupBindController
-        ~~~~~~~~~~~~~~~~~~~
-
-        コントローラーをバインドします
-        
-    ------------------------------"""
     def setupBindController(self):
+        u"""コントローラーをバインドします"""
         self.controllerPath = os.path.join(self.appPath, self.controllerFolder)
         if not os.path.isdir(self.controllerPath):
             raise ShimehariSetupError('Controller in the specified directory does not exist. %s' % self.controllerPath)
 
         try:
             ctrlDir = self.appFolder + '.' + self.controllerFolder
-            ctrlMod = __import__(ctrlDir)
-            ctrls = getModulesFromPyFile(self.controllerPath, self.rootPath)
+            __import__(ctrlDir)
+            getModulesFromPyFile(self.controllerPath, self.rootPath)
         except (ImportError, AttributeError), error:
             raise ShimehariSetupError('setup controller was failed... \n%s' % error)
 
-
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        setupBindRouter
-        ~~~~~~~~~~~~~~~
-
-        ルーターをバインドします
-
-    ------------------------------"""
     def setupBindRouter(self):
+        u"""ルーターをバインドします。"""
         try:
             routerFile = self.appFolder + '.' + 'router'
             routerMod = __import__(routerFile, fromlist=['router'])
             if hasattr(routerMod, 'appRoutes'):
                 self.router = routerMod.appRoutes
+            if self.hasStaticFolder:
+                self.addRoute(self.staticURL + '/<path:filename>', self.sendStaticFile)
         except (ImportError, AttributeError), e:
             raise ShimehariSetupError('Failed to setup the router ...\n details::\n%s' % e)
 
-
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        beforeRequest
-        ~~~~~~~~~~~~~
-
-        リクエスト処理を行う前にする処理を
-        登録します。
-        [args]
-        :f
-            実行したい処理
-        [return]
-        :function
-            登録した処理
-    ------------------------------"""
     @setupMethod
     def beforeRequest(self, f):
-        self.beforeRequestFuncs.setdefault(None,[]).append(f)
+        u"""リクエストを処理する前に実行したいメソッドを登録します。
+
+        :param f: リクエスト処理前に実行させたい処理
+        """
+        self.beforeRequestFuncs.setdefault(None, []).append(f)
         return f
 
-
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        beforeFirstRequest
-        ~~~~~~~~~~~~~~~~~~
-
-        最初のリクエスト処理を行う前にする処理
-        [args]
-        :f
-            実行したい処理
-    ------------------------------"""
     @setupMethod
     def beforeFirstRequest(self, f):
+        u"""アプリケーションに対し初めてリクエストがあったときのみ、
+            リクエストを処理する前に実行したいメソッドを登録します。
+
+        :param f: 初めてのリクエスト処理前に実行したい処理
+        """
         self.beforeFirstRequestFuncs.append(f)
 
-
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        afterRequest
-        ~~~~~~~~~~~~
-
-        リクエストの後に処理
-        [args]
-        :f
-            実行したい処理
-    ------------------------------"""
     @setupMethod
     def afterRequest(self, f):
-        self.afterRequestFuncs.setdefault(None,[]).append(f)
+        u"""リクエスト処理が終わった後に実行したいメソッドを登録します。
+
+        :param f: リクエスト処理後に実行したい処理
+        """
+        self.afterRequestFuncs.setdefault(None, []).append(f)
         return f
 
-
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        urlValuePreprocessor
-        ~~~~~~~~~~~~~~~~~~~~
-
-        リクエストの前に処理
-        [args]
-        :f
-            実行したい処理
-    ------------------------------"""
     @setupMethod
     def urlValuePreprocessor(self, f):
+        u"""リクエストの前に実行したい処理を登録します。
+
+        :param f: 実行したい処理
+        """
         self.urlValuePreprocesors.setdefault(None, []).append(f)
         return f
 
-
-
     @setupMethod
     def tearDownAppContext(self, f):
         self.teardownAppContextFuncs.append(f)
         return f
 
-
     @setupMethod
     def errorHandler(self, codeOrException):
         def decorator(f):
@@ -497,149 +396,80 @@ class Shimehari(_Kouzi):
             assert codeOrException != 500 or key is None
             self.errorHandlerSpec.setdefault(key, {})[codeOrException] = f
         else:
-            self.errorHandlerSpec.setdefault(key, {}).setdefault(None,[]).append((codeOrException, f))
+            self.errorHandlerSpec.setdefault(key, {}).setdefault(None, []).append((codeOrException, f))
 
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        tryTriggerBeforeFirstRequest
-        ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
-        最初のリクエストがあった時のみに行う処理を実行します。
-    ------------------------------"""
     def tryTriggerBeforeFirstRequest(self):
+        u"""アプリケーションに対し最初のリクエストがあった時のみに行う処理を
+            実際に実行します。
+        """
         if self._gotFirstRequest:
-            return 
+            return
         with self._beforeRequestLock:
             if self._gotFirstRequest:
-                return 
+                return
             self._gotFirstRequest = True
             [f() for f in self.beforeFirstRequestFuncs]
 
-
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        createAdapter
-        ~~~~~~~~~~~~~
-
-        url adapter を生成します
-        [args]
-        :request
-            元となるリクエスト
-        [return]
-        :adapter
-            アダプター
-    ------------------------------"""
     def createAdapter(self, request):
+        u"""url adapter を生成します
+
+        :param request: 元となるリクエストオブジェクト
+
+
+        """
         if request is not None:
             return self.router.bind_to_environ(request.environ)
         #なんのこっちゃ
         if self.config['SERVER_NAME'] is not None:
             return self.router.bind(
-                self.config['SERVER_NAME'], 
+                self.config['SERVER_NAME'],
                 script_name=self.config['APP_ROOT'] or '/',
                 url_scheme=self.config['PREFERRED_URL_SCHEME'])
 
-
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        appContext
-        ~~~~~~~~~~
-        アプリケーションコンテキストを返します。
-        [args]
-        :environ
-            環境変数
-    ------------------------------"""
     def appContext(self):
+        u"""アプリケーションコンテキストを返します。"""
         return AppContext(self)
 
+    def requestContext(self, environ):
+        u"""リクエストコンテキストを返します。
 
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        requestContext
-        ~~~~~~~~~~~~~~
-        リクエストコンテキストを返します。
-        [args]
-        :environ
-            リクエスト環境変数
-    ------------------------------"""
-    def requestContext(self,environ):
+        :param environ: リクエスト環境変数
+        """
         return RequestContext(self, environ)
 
-
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        doAppContextTearDonw
-        ~~~~~~~~~~~~~~~~~~~~
-        アプリケーションコンテキストがティアーダウンしたとき実行します。
-        [args]
-        :exc
-            
-    ------------------------------"""
-    def doAppContextTearDonw(self,exc=None):
+    def doAppContextTearDonw(self, exc=None):
         if exc is None:
             exc = sys.exc_info()[1]
         for func in reversed(self.teardownAppContextFuncs):
             func(exc)
         appContextTearingDown.send(self, exc)
 
-
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        doRequestContextTearDown
-        ~~~~~~~~~~~~~~
-        リクエストコンテキストを返します。
-        未実装
-        [args]
-        :environ
-            環境変数
-    ------------------------------"""
-    def doRequestContextTearDown(self,exc=None):
+    def doRequestContextTearDown(self, exc=None):
         if exc is None:
             exc = sys.exc_info()[1]
-        for func in reversed(self.teardownRequestContextFuncs.get(None,())):
-            rv = func(exc)
-        requestContextTearingDown.send(self,exc=exc)
+        for func in reversed(self.teardownRequestContextFuncs.get(None, ())):
+            func(exc)
+        requestContextTearingDown.send(self, exc=exc)
 
-
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        preprocessRequest
-        ~~~~~~~~~~~~~~~~~
-
-        リクエスト前に実行したい処理たちを実行します。
-        [return]
-        :rv
-            登録した処理
-    ------------------------------"""
     def preprocessRequest(self):
+        u"""リクエスト前に処理したい登録済みのメソッドを実行します。
+
+        :param rv: 登録した処理
+        """
         for func in self.urlValuePreprocesors.get(None, ()):
-            func(request.endpoint, request.viewArgs) 
+            func(request.endpoint, request.viewArgs)
         self.csrf.checkCSRFExempt()
         self.csrf.csrfProtect()
         for func in self.beforeRequestFuncs.get(None, ()):
             rv = func()
-            if rv is not None:                
+            if rv is not None:
                 return rv
 
+    def processResponse(self, response):
+        u"""レスポンスを返す前に処理したい登録済みのメソッドをを実行します。
 
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        processResponse
-        ~~~~~~~~~~~~~~~
-        レスポンス前に行いたい処理を実行します。
-        [return]
-        :response
-            レスポンス
-    ------------------------------"""
-    def processResponse(self,response):
+        :param response: レスポンス
+        """
         context = _requestContextStack.top
         funcs = ()
 
@@ -647,27 +477,17 @@ class Shimehari(_Kouzi):
             funcs = self.afterRequestFuncs[None]
         for handler in funcs:
             response = handler(response)
-        
+
         if not self.sessionStore.isNullSession(context.session):
             self.saveSession(context.session, response)
         return response
 
-
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        dispatchRequest
-        ~~~~~~~~~~~~~~~
-        リクエストだす
-        [args]
-        :request
-            リクエスト
-
-        [return]
-        :response
-            レスポンス
-    ------------------------------"""
     def dispatchRequest(self):
+        u"""リクエストをもとに、レスポンスを発行します。
+
+        :param request: リクエスト
+
+        """
         self.tryTriggerBeforeFirstRequest()
         try:
             rv = self.preprocessRequest()
@@ -682,28 +502,19 @@ class Shimehari(_Kouzi):
 
         response = self.makeResponse(rv)
         response = self.processResponse(response)
-        
+
         return response
 
-
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        makeResponse
-        ~~~~~~~~~~~~
-        レスポンスを生成して返します。
-        [args]
-        :rv
-            リクエスト
-        [return]
-        :rv
-            レスポンス
-    ------------------------------"""
     def makeResponse(self, rv):
+        u"""レスポンスを生成して返します。
+
+        :param rv: リクエスト
+
+        """
         status = headers = None
 
-        if isinstance(rv,tuple):
-            rv, status, headers = rv + (None,) * (3-len(rv))
+        if isinstance(rv, tuple):
+            rv, status, headers = rv + (None,) * (3 - len(rv))
 
         if rv is None:
             raise ValueError('view function does not return a response.')
@@ -713,7 +524,7 @@ class Shimehari(_Kouzi):
                 rv = self.responseClass(rv, headers=headers, status=status)
                 headers = status = None
             else:
-                rv = self.responseClass.force_type(rv,request.environ)
+                rv = self.responseClass.force_type(rv, request.environ)
         if status is not None:
             if isinstance(status, basestring):
                 rv.status = status
@@ -723,21 +534,12 @@ class Shimehari(_Kouzi):
             rv.headers.extend(headers)
         return rv
 
-
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        handleException
-        ~~~~~~~~~~~~~~~
-        エラーをハンドリングします。
-
-        [args]
-        :e
-            エラー内容
-        [return]
-
-    ------------------------------"""
     def handleException(self, e):
+        u"""エラーをハンドリングします。
+
+        :param e: エラー内容
+
+        """
 
         excType, excValue, excTb = sys.exc_info()
         handler = self.errorHandlerSpec[None].get(500)
@@ -748,20 +550,17 @@ class Shimehari(_Kouzi):
             else:
                 raise e
 
-        self.logException((excType,excValue,excTb))
+        self.logException((excType, excValue, excTb))
         if handler is None:
             return InternalServerError()
         return handler(e)
 
-
-
     def handleHTTPException(self, e):
         handler = self.errorHandlerSpec[None].get(e.code)
         if handler is None:
             return e
         return handler(e)
 
-
     def trapHTTPException(self, e):
         if self.config['TRAP_HTTP_EXCEPTIONS']:
             return True
@@ -769,10 +568,10 @@ class Shimehari(_Kouzi):
             return isinstance(e, BadRequest)
         return False
 
-    def handleUserException(self,e):
+    def handleUserException(self, e):
         excType, excValue, tb = sys.exc_info()
         assert excValue is e
-        
+
         if isinstance(e, HTTPException) and not self.trapHTTPException(e):
             return self.handleHTTPException(e)
 
@@ -782,14 +581,11 @@ class Shimehari(_Kouzi):
                 return handler(e)
         raise excType, excValue, tb
 
-
     def raiseRoutingException(self, request):
         if not self.debug or not isinstance(request.routingException, RequestRedirect) \
            or request.method in ('GET', 'HEAD', 'OPTIONS'):
             raise request.routingException
 
-
-
     def testRequestContext(self, *args, **kwargs):
         from shimehari.testing import makeTestEnvironBuilder
         builder = makeTestEnvironBuilder(self, *args, **kwargs)
@@ -801,54 +597,34 @@ class Shimehari(_Kouzi):
     def handleBuildError(self, error, endpoint, **kwargs):
         if self.buildErrorHandlers is None:
             excType, excValue, tb = sys.exc_info()
-            if excValue is error :
+            if excValue is error:
                 raise excType, excValue, tb
             else:
                 raise error
         return self.buildErrorHandlers(error, endpoint, **kwargs)
 
-
-
-
-    u"""-----------------------------
-        ::pkg:: Shimehari.app
-        wsgiApp
-        ~~~~~~~
-
-        WSGI アプリとして実行します。(であってるのか)
-        [args]
-        :environ
-            環境変数
-        :startResponse
-            hoge
-    ------------------------------"""
     def wsgiApp(self, environ, startResponse):
+        u"""WSGI アプリとして実行します。(であってるのか)
+
+        :param environ:         環境変数
+        :param startResponse:   hoge
+
+        """
         with self.requestContext(environ):
             try:
                 response = self.dispatchRequest()
             except Exception, e:
                 response = self.makeResponse(self.handleException(e))
             return response(environ, startResponse)
-        
 
-
-    u"""--------------------------------------
-        ::pkg:: Shimehari.app
-        drink
-        ~~~~~    
-
-        アプリを走らせます。
-        [args]
-        :host
-            ホスト名
-        :port
-            ポート番号
-        :debug
-            デバッグモードとして起動するかどうか
-        :options
-            kwargs
-    --------------------------------------"""
     def drink(self, host=None, port=None, debug=None, **options):
+        u"""アプリを実行します。
+
+        :param host:    ホスト名
+        :param port:    ポート番号
+        :param debug:   デバッグモードとして起動するかどうか
+        :param options: kwargs
+        """
         from werkzeug.serving import run_simple
         if host is None:
             host = '127.0.0.1'
@@ -860,26 +636,17 @@ class Shimehari(_Kouzi):
         options.setdefault('use_debugger', self.debug)
         try:
             from werkzeug._internal import _log
-            _log('info',' * Shimehari GKGK!')
+            _log('info', ' * Shimehari GKGK!')
             run_simple(host, port, self, **options)
         finally:
             self._gotFirstRequest = False
 
-
-
-    u"""--------------------------------------
-        ::pkg:: Shimenari.app
-        run
-        ~~~
-
-        アプリを走らせます。
-        drink のラッパー。
-        WSGI 周りのライブラリとかで
-        run を自動的に呼ぶ物対策
-    --------------------------------------"""
-    def run(self,host=None,port=None, debug=None, **options):
-        self.drink(host,port,debug,options)
-
+    def run(self, host=None, port=None, debug=None, **options):
+        u"""アプリを実行します。
+            単純に drink メソッドをラップしているだけです。
+            WSGI 周りのライブラリや既存のコードで run を自動的に呼ぶ物がおおいので念のため。
+        """
+        self.drink(host, port, debug, options)
 
     def testClient(self, useCookies=True):
         cls = self.testClientCls
@@ -887,13 +654,8 @@ class Shimehari(_Kouzi):
             from shimehari.testing import ShimehariClient as cls
         return cls(self, self.responseClass, use_cookies=useCookies)
 
-
-
-    def __call__(self,environ,startResponse):
-        return self.wsgiApp(environ,startResponse)
-
-
+    def __call__(self, environ, startResponse):
+        return self.wsgiApp(environ, startResponse)
 
     def __str__(self):
         return 'Shimehari WSGI Application Framework!'
-
