@@ -38,9 +38,11 @@ from werkzeug.datastructures import Headers
 from werkzeug.wsgi import wrap_file
 from werkzeug.urls import url_quote
 from werkzeug.routing import BuildError
+from werkzeug.exceptions import NotFound
 from shimehari.shared import currentApp, request, _appContextStack, _requestContextStack
 from shimehari.core.helpers import importFromString
 
+
 def _assertHaveJson():
     if not jsonAvailable:
         raise RuntimeError(u'json ないじゃん')
@@ -53,29 +55,24 @@ try:
 except ImportError:
     redisAvailable = False
 
+
 def _assertHaveRedis():
     if not redisAvailable:
         raise RuntimeError('no redis module found')
 
 
-
 _osAltSep = list(sep for sep in [os.path.sep, os.path.altsep] if sep not in (None, '/'))
 
 _missing = object()
 
 _toJsonFilter = json.dumps
 
-u"""-----------------------------
-    ::pkg:: Shimehari.helpers
-    getHandlerAction
-    ~~~~~~~~~~~~~~~~
 
-    [args]
-    :resource
-
-        
-----------------------------------"""
 def getHandlerAction(resource, action):
+    u"""与えられたコントローラーとアクション名からマッチするハンドラを返します。
+    :param resource:    ハンドラを抱えているコントローラー
+    :param action:      ハンドラを取得したいアクション
+    """
     try:
         handler = getattr(resource, action)
         if callable(handler):
@@ -84,45 +81,33 @@ def getHandlerAction(resource, action):
         pass
 
 
-u"""-----------------------------
-    ::pkg:: Shimehari.helpers
-    getHostName
-    ~~~~~~~~~~~
-
-    URL からホスト名を取得します。
-    [args]
-    :url
-        ホスト名を抜き出したい URL
-        
-----------------------------------"""
 def getHostName(url):
+    u"""URL からホスト名を取得します。
+
+    :param url: ホスト名を抜き出したい URL
+
+    """
     return urlparse.urlparse(url).netloc
 
 
-
-u"""--------------------------------------
-    ::pkg:: Shimehari.helpers
-    stripTags
-    ~~~~~~~~~
-
-    HTML タグを除去
---------------------------------------"""
 import sgmllib
+
+
 class Stripper(sgmllib.SGMLParser):
+    u"""与えられたストリングから HTML タグを除去するクラス。"""
     def __init__(self):
         sgmllib.SGMLParser.___init__(self)
 
-    def strip(self,htmlTag):
+    def strip(self, htmlTag):
         self.theString = ""
         self.feed(htmlTag)
         self.close()
         return self.theString
 
-    def handleData(self,data):
+    def handleData(self, data):
         self.theString += data
 
 
-
 def urlFor(endpoint, **values):
     appctx = _appContextStack.top
     reqctx = _requestContextStack.top
@@ -134,7 +119,7 @@ def urlFor(endpoint, **values):
         urlAdapter = reqctx.urlAdapter
         # if urlAdapter is None:
             # raise RuntimeError('ooooo')
-        if endpoint[:1]==('.'):
+        if endpoint[:1] == ('.'):
             endpoint = endpoint[1:]
         external = values.pop('_external', False)
     else:
@@ -142,7 +127,7 @@ def urlFor(endpoint, **values):
         if urlAdapter is None:
             raise RuntimeError('url adapter not found')
         external = values.pop('_external', True)
-    
+
     anchor = values.pop('_anchor', None)
     method = values.pop('_method', None)
     appctx.app.injectURLDefaults(endpoint, values)
@@ -162,7 +147,6 @@ def urlFor(endpoint, **values):
     return rv
 
 
-
 def findPackage(importName):
     rootModName = importName.split('.')[0]
     loader = pkgutil.get_loader(rootModName)
@@ -197,7 +181,6 @@ def findPackage(importName):
     return None, pkgPath
 
 
-
 u"""-----------------------------
     ::pkg:: Shimehari.helpers
     getModulesFromPyFile
@@ -212,20 +195,21 @@ u"""-----------------------------
     [return]
     :modules
         インポートされたモジュール
-        
+
 ----------------------------------"""
 import glob
+
+
 def getModulesFromPyFile(targetPath, rootPath):
     files = glob.glob(targetPath + '/*.py')
     modules = []
     for fn in files:
         if not '__init__' in fn:
-            fn = fn.replace(rootPath, '')[1:].replace('.py','').replace('/', '.')
+            fn = fn.replace(rootPath, '')[1:].replace('.py', '').replace('/', '.')
             modules.append(fn)
     return modules
 
 
-
 u"""-----------------------------
     ::pkg:: Shimehari.helpers
     getRootPath
@@ -238,8 +222,10 @@ u"""-----------------------------
 
     [return]
         :string ルートパス
-        
+
 ----------------------------------"""
+
+
 def getRootPath(importName):
     loader = pkgutil.get_loader(importName)
     if loader is None or importName == '__main__':
@@ -253,7 +239,6 @@ def getRootPath(importName):
     return os.path.dirname(os.path.abspath(filePath))
 
 
-
 u"""-----------------------------
     ::pkg:: Shimehari.helpers
     getEnviron
@@ -263,24 +248,25 @@ u"""-----------------------------
     [return]
     :url
         ホスト名を抜き出したい URL
-        
+
 ----------------------------------"""
+
+
 def getEnviron():
     if 'SHIMEHARI_WORK_ENV' in os.environ:
         return os.environ['SHIMEHARI_WORK_ENV']
     return 'development'
 
 
-
 def sendFromDirectory(directory, filename, **options):
     filename = safeJoin(directory, filename)
     if not os.path.isfile(filename):
+        print filename
         raise NotFound()
-    options.setdefault('conditional',True)
+    options.setdefault('conditional', True)
     return sendFile(filename, **options)
 
 
-
 def safeJoin(directory, filename):
     filename = os.path.normpath(filename)
     for sep in _osAltSep:
@@ -291,21 +277,15 @@ def safeJoin(directory, filename):
     return os.path.join(directory, filename)
 
 
-
-u"""-----------------------------
-    ::pkg:: Shimehari.helpers
-    sendFile
-    ~~~~~~~~
-
-    静的ファイルをレスポンスとして返します。
-    [return]
-    :response
-        静的ファイル
-        
-----------------------------------"""
 def sendFile(filenameOrFp, mimetype=None, asAttachment=False,
              attachmentFilename=None, addEtags=True,
              cacheTimeout=None, conditional=False):
+    u"""静的ファイルをレスポンスとして返します。
+
+    :param filenameOrFp:    送りたいファイル名
+    :param mimetype:        mimetype
+
+    """
     mtime = None
     if isinstance(filenameOrFp, basestring):
         filename = filenameOrFp
@@ -320,10 +300,10 @@ def sendFile(filenameOrFp, mimetype=None, asAttachment=False,
             warn(DeprecationWarning('THAAAAAAAA'), stacklevel=2)
         if addEtags:
             warn(DeprecationWarning('AAAAAAA?'), stacklevel=2)
-        
+
     if filename is not None:
         if not os.path.isabs(filename):
-            filname = os.path.join(currentApp.rootPath, filename)
+            os.path.join(currentApp.rootPath, filename)
     if mimetype is None and (filename or attachmentFilename):
         mimetype = mimetypes.guess_type(filename or attachmentFilename)[0]
     if mimetype is None:
@@ -335,7 +315,7 @@ def sendFile(filenameOrFp, mimetype=None, asAttachment=False,
             if filename is None:
                 raise TypeError('file name is invalid')
             attachmentFilename = os.path.basename(filename)
-        headers.add('Content-Disposition','attachment',filename=attachmentFilename)
+        headers.add('Content-Disposition', 'attachment', filename=attachmentFilename)
 
     if currentApp.useXSendFile and filename:
         if file is not None:
@@ -363,13 +343,14 @@ def sendFile(filenameOrFp, mimetype=None, asAttachment=False,
         rv.expires = int(time() + cacheTimeout)
 
     if addEtags and filename is not None:
-        rv.set_etag('Shimehari-%s-%s-%s' % 
-            (os.path.getmtime(filename), 
-            os.path.getsize(filename), 
+        rv.set_etag('Shimehari-%s-%s-%s' %
+            (os.path.getmtime(filename),
+            os.path.getsize(filename),
             adler32(
                 filename.encode('utf8') if isinstance(filename, unicode) else filename
             ) & 0xffffffff
-        ))
+            )
+        )
 
     if conditional:
         rv = rv.make_conditional(request)
@@ -392,9 +373,8 @@ def jsonify(*args, **kwargs):
         content = str(callback) + '(' + jsonStr + ')'
         return currentApp.responseClass(content, mimetype='application/javascript')
     """
-    return currentApp.responseClass(json.dumps(dict(*args,**kwargs), \
-        indent=None if request.is_xhr else 2), mimetype='application/json')
-
+    resp = json.dumps(dict(*args, **kwargs), indent=None if request.is_xhr else 2)
+    return currentApp.responseClass(resp, mimetype='application/json')
 
 
 def fillSpace(text, length):
@@ -405,7 +385,6 @@ def fillSpace(text, length):
     return text
 
 
-from threading import RLock
 class lockedCachedProperty(object):
     def __init__(self, func, name=None, doc=None):
         self.__name__ = name or func.__name__
@@ -425,7 +404,6 @@ class lockedCachedProperty(object):
             return value
 
 
-
 def getTemplater(app, templaterName, *args, **options):
     import shimehari
     templateDir = os.path.join(shimehari.__path__[0], 'template', templaterName)
@@ -444,21 +422,22 @@ u"""--------------------------------------
     ~~~~~~~~~~~~~~~~~~~~~~~~
     Shimehari のベーシッククラス
 --------------------------------------"""
+
+
 class _Kouzi(object):
-    def __init__( self, importName, appFolder='app', 
+    def __init__(self, importName, appFolder='app',
                   controllerFolder='controllers', viewFolder=None):
         self.importName = importName
         self.currentEnv = getEnviron()
-        
+
         self.rootPath = getRootPath(self.importName)
-        
 
         from shimehari.configuration import ConfigManager
         config = ConfigManager.getConfig(self.currentEnv)
 
-        if config and self.rootPath == os.getcwd() +'/' + config['APP_DIRECTORY']:
+        if config and self.rootPath == os.getcwd() + '/' + config['APP_DIRECTORY']:
             self.rootPath = os.getcwd()
-        
+
         self.appFolder = config['APP_DIRECTORY'] if config and config['APP_DIRECTORY'] else appFolder
         self.controllerFolder = config['CONTROLLER_DIRECTORY'] if config and \
                                 config['CONTROLLER_DIRECTORY'] else controllerFolder
@@ -469,7 +448,8 @@ class _Kouzi(object):
 
     def _getStaticFolder(self):
         if self._staticFolder is not None:
-            return os.path.join(self.rootPath, self._staticFolder)
+            return os.path.join(self.rootPath, self.appFolder, self._staticFolder)
+
     def _setStaticFolder(self, value):
         self._staticFolder = value
     staticFolder = property(_getStaticFolder, _setStaticFolder)
@@ -480,18 +460,16 @@ class _Kouzi(object):
             if self.staticFolder is None:
                 return None
             return '/' + os.path.basename(self.staticFolder)
+
     def _setStaticURL(self, value):
         self._staticURL = value
     staticURL = property(_getStaticURL, _setStaticURL)
     del _getStaticURL, _setStaticURL
 
-
-
     @property
     def hasStaticFolder(self):
         return self.staticFolder is not None
 
-
     u"""-----------------------------
         ::pkg:: Shimehari.helpers._Kouzi
         sendStaticFile
@@ -503,7 +481,7 @@ class _Kouzi(object):
 
         [return]
         :response レスポンス
-        
+
     ----------------------------------"""
     def sendStaticFile(self, filename):
         if not self.hasStaticFolder:
@@ -511,8 +489,6 @@ class _Kouzi(object):
         cacheTimeout = self.getSendFileMaxAge(filename)
         return sendFromDirectory(self.staticFolder, filename, cacheTimeout=cacheTimeout)
 
-
-
     u"""-----------------------------
         ::pkg:: Shimehari.helpers._Kouzi
         getSendFileMaxAge
@@ -524,14 +500,12 @@ class _Kouzi(object):
 
         [return]
         :response レスポンス
-        
+
     ----------------------------------"""
     def getSendFileMaxAge(self, filename):
         return currentApp.config['SEND_FILE_MAX_AGE_DEFAULT']
 
-
     def openFile(self, filename, mode='rb'):
         if mode not in ('r', 'rb'):
             raise ValueError('can not read file')
-        return open(os.path.join(self.rootPath,filename), mode)
-
+        return open(os.path.join(self.rootPath, filename), mode)
