@@ -19,7 +19,7 @@ from shimehari.core.helpers import importPreferredMemcachedClient
 try:
     import msgpack as msg
 except ImportError:
-    try: 
+    try:
         import cpickle as msg
     except ImportError:
         import pickle as msg
@@ -29,7 +29,6 @@ except ImportError:
         from shimehari.helpers import json as msg
 
 
-
 u"""
 ===============================
     ::pkg:: Shimehari.sessions
@@ -37,9 +36,11 @@ u"""
     ~~~~~~~~~~~~
 
     セッションの機能をもたせます
-    
+
 ===============================
 """
+
+
 class SessionMixin(object):
     def _get_permanent(self):
         return self.get('_permanent', False)
@@ -54,7 +55,6 @@ class SessionMixin(object):
     modified = True
 
 
-
 u"""
 ===============================
     ::pkg:: Shimehari.sessions
@@ -62,23 +62,27 @@ u"""
     ~~~~~~~~~~~~~~~~~~~
 
     SecureCookie を使ったセッション
-    
+
 ===============================
 """
-class SecureCookieSession(SecureCookie, SessionMixin):    
-    u"""Secure Cookie つかった session"""
-    def __init__(self,  initial=None, sid=None, new=False):
+
+
+class SecureCookieSession(SecureCookie, SessionMixin):
+    u"""SecureCookie を使ったセッションクラス
+
+    :param initial:     セッションデータ
+    :param sid:         セッションID
+    :param new:         新規セッション
+    """
+    def __init__(self, initial=None, sid=None, new=False):
         def on_update(self):
             self.modified = True
-        # SecureCookie.__init__(self, initial, on_update)
+        SecureCookie.__init__(self, initial, on_update)
         self.sid = sid
         self.new = new
         self.modified = False
 
 
-
-
-
 u"""
 ===============================
     ::pkg:: Shimehari.sessions
@@ -86,9 +90,11 @@ u"""
     ~~~~~~~~~~~
 
     物言わぬセッション
-    
+
 ===============================
 """
+
+
 class NullSession(Session):
     def _fail(self, *args, **kwargs):
         raise RuntimeError('Null Session!!!')
@@ -97,7 +103,6 @@ class NullSession(Session):
     del _fail
 
 
-
 u"""
 ===============================
     ::pkg:: Shimehari.sessions
@@ -105,9 +110,11 @@ u"""
     ~~~~~~~~~~~~~
 
     werkzeug のセッションストアに多少機能を追加します。
-    
+
 ===============================
 """
+
+
 class _SessionStore(SessionStoreBase):
     nullSessionClass = NullSession
 
@@ -121,25 +128,21 @@ class _SessionStore(SessionStoreBase):
         return self.nullSessionClass()
 
 
-
-u"""
-===============================
-    ::pkg:: Shimehari.sessions
-    MemcachedSessionStore
-    ~~~~~~~~~~~~~~~~~~~~~
-
-    セッションの保存先として Memcache を
-    使用します。
-    
-===============================
-"""
 from pickle import HIGHEST_PROTOCOL
-class MemcachedSessionStore(_SessionStore):
-    """session store using memcache"""
-    def __init__(self,servers=None, keyPrefix=None, defaultTimeout=300, session_class=None):
-        _SessionStore.__init__(self,session_class=session_class)
 
-        if isinstance(servers, (list,tuple)):
+
+class MemcachedSessionStore(_SessionStore):
+    u"""セッションの保存先に Memcache を使ったセッションストア
+
+    :param servers:         Memcache サーバー
+    :param keyPrefix:       セッション格納時、キーに付ける接頭詞
+    :param defaultTimeout:  セッションの保存期間
+    :param session_class:   セッションクラス
+    """
+    def __init__(self, servers=None, keyPrefix=None, defaultTimeout=300, session_class=None):
+        _SessionStore.__init__(self, session_class=session_class)
+
+        if isinstance(servers, (list, tuple)):
             client = importPreferredMemcachedClient(servers)
         elif servers is not None:
             client = servers
@@ -163,14 +166,14 @@ class MemcachedSessionStore(_SessionStore):
             return self.new()
 
         key = self._getMemcacheKey(sid)
-        data = self._memcacheClient.get(key)
+        packed = self._memcacheClient.get(key)
         try:
             data = msg.loads(packed)
         except TypeError:
             data = {}
         return self.session_class(data, sid, False)
 
-    def _getMemcacheKey(self,sid):
+    def _getMemcacheKey(self, sid):
         if self._memcacheKeyPrefix:
             key = self._memcacheKeyPrefix + sid
         else:
@@ -180,21 +183,13 @@ class MemcachedSessionStore(_SessionStore):
         return key
 
 
-
-u"""
-===============================
-    ::pkg:: Shimehari.sessions
-    SecureCookieSessionStore
-    ~~~~~~~~~~~~~~~~~~~~~~~~
-
-    SecureCookieSession を利用したセッションストア
-    
-===============================
-"""
 from shimehari.shared import request
+
+
 class SecureCookieSessionStore(_SessionStore):
+    u"""SecureCookieSession を利用したセッションストア"""
     def __init__(self, key='session', expire=0):
-        _SessionStore.__init__(self,session_class=SecureCookieSession)
+        _SessionStore.__init__(self, session_class=SecureCookieSession)
         self.key = key
         #直せ
         self.path = '/'
@@ -220,23 +215,13 @@ class SecureCookieSessionStore(_SessionStore):
             return self.session_class.load_cookie(request, self.key, secret_key=self.key)
 
 
-
-
-
-u"""
-===============================
-    ::pkg:: Shimehari.session
-    RedisSessionStore
-    ~~~~~~~~~~~~~~~~~
-
-    Author: @soundkitchen Izukawa Takanobu 
-    Redis を使ったセッションストア
-    
-===============================
-"""
-
 class RedisSessionStore(_SessionStore):
-    """session store using redis."""
+    u"""Redis を使ったセッションストア
+
+    Author: @soundkitchen Izukawa Takanobu
+
+    :param
+    """
     def __init__(self, host='localhost', port=6379, db=0, expire=0, session_class=None):
         from redis import Redis
         super(RedisSessionStore, self).__init__(session_class=session_class)
@@ -264,16 +249,16 @@ class RedisSessionStore(_SessionStore):
         return self.session_class(data, sid, False)
 
 
-"""デフォルトのセッションストアを決定します。"""
+u"""デフォルトのセッションストアを決定します。"""
 try:
     from werkzeug.contrib.sessions import FileSystemSessionStore
     _currentStore = FileSystemSessionStore()
 except (Exception, RuntimeError), e:
     try:
-        """GAE 対策"""
+        u"""GAE 対策"""
         _currentStore = MemcachedSessionStore()
     except (Exception, RuntimeError), e:
-        """それでもダメだったら最後の手段"""
+        u"""それでもダメだったら最後の手段"""
         _currentStore = SecureCookieSessionStore()
 finally:
-    SessionStore = _currentStore.__class__
\ No newline at end of file
+    SessionStore = _currentStore.__class__
