@@ -6,14 +6,16 @@ u"""
     Shimehari.shared
     ~~~~~~~~~~~~~~~~
     アプリケーション内で共通して使いたい物たち
-    
+
 ===============================
 """
 from functools import partial
 from werkzeug.local import LocalProxy, LocalStack
 
 
-class _SharedRequestClass(object): pass
+class _SharedRequestClass(object):
+    pass
+
 
 def _lookUpObjectInRequestContext(name):
     top = _requestContextStack.top
@@ -21,6 +23,7 @@ def _lookUpObjectInRequestContext(name):
         raise RuntimeError('ahixi...')
     return getattr(top, name)
 
+
 def findApp():
     top = _appContextStack.top
     if top is None:
@@ -28,9 +31,9 @@ def findApp():
     return top.app
 
 
-_requestContextStack= LocalStack()
-_appContextStack  = LocalStack()
+_requestContextStack = LocalStack()
+_appContextStack = LocalStack()
 currentApp = LocalProxy(findApp)
 request = LocalProxy(partial(_lookUpObjectInRequestContext, 'request'))
 session = LocalProxy(partial(_lookUpObjectInRequestContext, 'session'))
-shared = LocalProxy(partial(_lookUpObjectInRequestContext, 'shared'))
\ No newline at end of file
+shared = LocalProxy(partial(_lookUpObjectInRequestContext, 'shared'))
